==> drf_otp_permissions-0.3.1.tar.gz: drf_otp_permissions-0.3.1/drf_otp_permissions/permissions.py <==
"""
Provides a set of pluggable OTP permission policies.
"""
from __future__ import unicode_literals

from django.conf import settings
from django.core.mail import send_mail

from rest_framework.permissions import BasePermission

from .otp import validate_otp


class IsValidOneTimePassword(BasePermission):
    """
    Allows access only to request with valid OTP in its header.
    """

    def has_permission(self, request, view):
        if request.user and request.user.is_superuser:
            return True

        if hasattr(view, 'get_otp_key_location'):
            key_location = view.get_otp_key_location()
        else:
            key_location = getattr(view, 'otp_key_location', None)

        otp = request.META.get('HTTP_X_OTP', None)
        if not otp:
            otp = request.META.get('HTTP_X-OTP', None)
        if not otp:
            return False

        if type(request.data) is dict:
            data = request.data
        else:
            data = request.data.dict()

        if not validate_otp(otp, data, key_location):
            admin_email_list = []
            for name, email in settings.ADMINS:
                admin_email_list.append(email)

            send_mail(
                'Attempt with Invalid OTP',
                'Request with invalid OTP has occurred at %s.' % self.__class__.__name__,
                settings.EMAIL_HOST_USER,
                admin_email_list,
                fail_silently=True,
            )
            return False
        return True

==> drf_otp_permissions-0.4.0.tar.gz: drf_otp_permissions-0.4.0/drf_otp_permissions/permissions.py <==
"""
Provides a set of pluggable OTP permission policies.
"""
from __future__ import unicode_literals

from django.conf import settings
from django.core.mail import send_mail

from rest_framework.permissions import BasePermission

from .otp import validate_otp


class IsValidOneTimePassword(BasePermission):
    """
    Allows access only to request with valid OTP in its header.
    """

    def has_permission(self, request, view):
        if request.user:
            if getattr(settings, 'DRF_OTP_PERMISSIONS_ALLOW_STAFF', True) and request.user.is_staff:
                return True
            if getattr(settings, 'DRF_OTP_PERMISSIONS_ALLOW_SUPERUSER', True) and request.user.is_superuser:
                return True

        if hasattr(view, 'get_otp_key_location'):
            key_location = view.get_otp_key_location()
        else:
            key_location = getattr(view, 'otp_key_location', None)

        otp = request.META.get('HTTP_X_OTP', None)
        if not otp:
            otp = request.META.get('HTTP_X-OTP', None)
        if not otp:
            return False

        if type(request.data) is dict:
            data = request.data
        else:
            data = request.data.dict()

        if not validate_otp(otp, data, key_location):
            admin_email_list = []
            for name, email in settings.ADMINS:
                admin_email_list.append(email)

            send_mail(
                'Attempt with Invalid OTP',
                'Request with invalid OTP has occurred at %s.' % self.__class__.__name__,
                settings.EMAIL_HOST_USER,
                admin_email_list,
                fail_silently=True,
            )
            return False
        return True
